# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Add radiance Sensor Grids and/or Views to a Honeybee Model.
_
This assignment is necessary for any Radiance study, though whether a grid or a
view is required for a particular type of study is depenednet upon the recipe
used.

-

    Args:
        _model: A Honeybee Model to which the input grids_ and views_ will be assigned.
        grids_: A list of Honeybee-Radiance SensorGrids, which will be assigned to
            the input _model.
        views_: A list of Honeybee-Radiance Views, which will be assigned to the
            input _model.

    Returns:
        model: The input Honeybee Model with the grids_ and views_ assigned to it.
"""

ghenv.Component.Name = 'HB Assign Grids and Views'
ghenv.Component.NickName = 'AssignGridsViews'
ghenv.Component.Message = '1.2.0'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '0 :: Basic Properties'
ghenv.Component.AdditionalHelpFromDocStrings = '5'

try:  # import core honeybee dependencies
    from honeybee.model import Model
except ImportError as e:
    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))

try:  # import ladybug_rhino dependencies
    from ladybug_rhino.grasshopper import all_required_inputs
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component):
    assert isinstance(_model, Model), \
        'Expected Honeybee Model. Got {}.'.format(type(_model))
    model = _model.duplicate()  # duplicate to avoid editing the input
    if len(grids_) != 0:
        model.properties.radiance.sensor_grids = grids_
    if len(views_) != 0:
        model.properties.radiance.views = views_



# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Get Radiance Sensor Grids and/or Views from a Honeybee Model and visualize them
in the Rhino scene.
-

    Args:
        _model: A Honeybee Model for which grids and views will be output.

    Returns:
        views: A list of Honeybee-Radiance Views that are assigned to the
            input _model.
        grids: A list of Honeybee-Radiance SensorGrids that are assigned to
            the input _model.
        points: The points that are at the center of each grid cell.
        meshes: Mesh for each sensor grid, which can be passed to the "LB Spatial
            Heatmap" component.
"""

ghenv.Component.Name = 'HB Get Grids and Views'
ghenv.Component.NickName = 'GetGridsViews'
ghenv.Component.Message = '1.2.0'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '0 :: Basic Properties'
ghenv.Component.AdditionalHelpFromDocStrings = '5'

try:  # import core ladybug_geometry dependencies
    from ladybug_geometry.geometry3d.pointvector import Point3D
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_geometry:\n\t{}'.format(e))

try:  # import core honeybee dependencies
    from honeybee.model import Model
except ImportError as e:
    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))

try:  # import ladybug_rhino dependencies
    from ladybug_rhino.fromgeometry import from_point3d, from_mesh3d
    from ladybug_rhino.grasshopper import all_required_inputs, list_to_data_tree
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component):
    assert isinstance(_model, Model), \
        'Expected Honeybee Model. Got {}.'.format(type(_model))
    # get the honeybee-radiance objects
    views = _model.properties.radiance.views
    grids = _model.properties.radiance.sensor_grids

    # get the visualizable attributes
    points = [[from_point3d(Point3D.from_array(s.pos)) for s in sg] for sg in grids]
    points = list_to_data_tree(points)
    meshes = []
    for grid in grids:
        if grid.mesh is not None:
            meshes.append(from_mesh3d(grid.mesh))



# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>


"""
Deconstruct a modifier into a radiance string.
-

    Args:
        _mod: A modifier to be deconstructed or text for a modifier to be looked
            up in the modifier library.

    Returns:
        rad_str: A Radiance string that includes all of the attributes that
            define the modifier.
"""

ghenv.Component.Name = 'HB Deconstruct Modifier'
ghenv.Component.NickName = 'DecnstrMod'
ghenv.Component.Message = '1.2.0'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '1 :: Modifiers'
ghenv.Component.AdditionalHelpFromDocStrings = '0'


try:  # import the honeybee-radiance dependencies
    from honeybee_radiance.lib.modifiers import modifier_by_identifier
except ImportError as e:
    raise ImportError('\nFailed to import honeybee_radiance:\n\t{}'.format(e))

try:  # import ladybug_rhino dependencies
    from ladybug_rhino.grasshopper import all_required_inputs
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component):
    # check the input
    if isinstance(_mod, str):
        _mod = modifier_by_identifier(_mod)
    rad_str = _mod.to_radiance()



# Honeybee: A Plugin for Environmental Analysis (GPL) started by Mostapha Sadeghipour Roudsari
# This file is part of Honeybee.
#
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Annual Daylight Metrics.

-

    Args:
        _results: An list of annual Radiance result files from the "HB Annual Daylight"
            component.  This should include both the .ill files and the
            sun-up-hours.txt
        _occ_sch_: An annual occupancy schedule as a Ladybug Data Collection or a HB-Energy
            schedule object. This can also be the identifier of a schedule in
            your HB-Energy schedule library. Any value in this schedule that is
            0.5 or above will be considered occupied. If None, a schedule from
            9AM to 5PM on weekdays will be used.
        _threshold_: Threshhold for daylight autonomy in lux (default: 300).
        _min_max_: A list for min, max value for useful daylight illuminance
                (default: (100, 3000)).

    Returns:
        report: Reports, errors, warnings, etc.
        DA: Daylight autonomy. The percentage of time that each sensor
            recieves equal or more than the threshold.
        UDI: Useful daylight illuminance. The percentage of time that illuminace
            falls between minimum and maximum thresholds.
        UDI_low: Numbers for the percent of time that is below the lower threshold
            of useful daylight illuminance.
        UDI_up: Numbers for the percent of time that is above the upper threshold
            of useful daylight illuminance.
"""

ghenv.Component.Name = "HB Annual Daylight Metrics"
ghenv.Component.NickName = 'AnnualMetrics'
ghenv.Component.Message = '1.2.1'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '4 :: Results'
ghenv.Component.AdditionalHelpFromDocStrings = '1'

try:
    from ladybug.datacollection import BaseCollection
except ImportError as e:
    raise ImportError('\nFailed to import ladybug:\n\t{}'.format(e))

try:
    from honeybee_energy.lib.schedules import schedule_by_identifier
except ImportError as e:  # honeybee schedule library is not available
    schedule_by_identifier = None

try:
    from ladybug_rhino.grasshopper import all_required_inputs, list_to_data_tree
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


def generate_default_schedule():
    """Create a list of 8760 values for a default occupancy schedule."""
    weekend = [0] * 24
    weekday = [0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0]
    all_vals = []
    day_counter = 0
    week_counter = 1
    while day_counter < 365:
        day_counter += 1
        if week_counter < 7:
            if week_counter == 1:
                all_vals.extend(weekend)
            else:
                all_vals.extend(weekday)
            week_counter += 1
        else:
            all_vals.extend(weekend)
            week_counter = 1
    return all_vals


def parse_sun_up_hours(result_files, schedule):
    """Parse the sun-up hours from the result file .txt file.

    Args:
        result_files: A list of result files that contains the .txt file.
        schedule: A list of 8760 values for the occupancy schedule.
    """
    for i, r_file in enumerate(result_files):
        if r_file.endswith('.txt'):
            with open(r_file) as soh_f:
                occ_pattern = [schedule[int(float(h))] for h in soh_f]
            result_files.pop(i)  # remove it from the list
            return occ_pattern


def annual_metrics(ill_file, occ_pattern, total_occupied_hours,
                   threshold=300, min_t=100, max_t=2000):
    """Compute annual metrics for a given result file."""
    da, udi, udi_low, udi_up  = [], [], [], []
    with open(ill_file) as results:
        for pt_res in results:
            pda, pudi, pudi_low, pudi_up = 0, 0, 0, 0
            for is_occ, hourly_res in zip(occ_pattern, pt_res.split()):
                if is_occ < 0.5:
                    continue
                value = float(hourly_res)
                if value > threshold:
                    pda += 1
                if value < min_t:
                    pudi_low += 1
                elif value <= max_t:
                    pudi += 1
                else:
                    pudi_up += 1
            da.append(round(100.0 * pda / total_occupied_hours, 2))
            udi.append(round(100.0 * pudi / total_occupied_hours, 2))
            udi_low.append(round(100.0 * pudi_low / total_occupied_hours, 2))
            udi_up.append(round(100.0 * pudi_up / total_occupied_hours, 2))
    return da, udi, udi_low, udi_up



if all_required_inputs(ghenv.Component):
    # set default values for the thresholds
    _threshold_ = _threshold_ if _threshold_ else 300
    if len(_min_max_) != 0:
        assert len(_min_max_), 'Expected two values for _min_max_.'
        min_t = _min_max_[0]
        max_t = _min_max_[1]
    else:
        min_t = 100
        max_t = 2000

    # process the schedule and sun-up hours
    if _occ_sch_ is None:
        schedule = generate_default_schedule()
    elif isinstance(_occ_sch_, BaseCollection):
        schedule = _occ_sch_.values
    elif isinstance(_occ_sch_, str):
        if schedule_by_identifier is not None:
            schedule = schedule_by_identifier(_occ_sch_).values()
        else:
            raise ValueError('honeybee-energy must be installed to reference '
                             'occupancy schedules by identifier.')
    else:  # assume that it is a honeybee schedule object
        schedule = _occ_sch_.values()
    total_occupied_hours = sum(schedule)
    occ_pattern = parse_sun_up_hours(_results, schedule)

    # compute the annual metrics
    DA, UDI, UDI_low, UDI_up = [], [], [], []
    for ill_file in _results:
        da, udi, udi_low, udi_up = \
            annual_metrics(ill_file, occ_pattern, total_occupied_hours,
                           _threshold_, min_t, max_t)
        DA.append(da)
        UDI.append(udi)
        UDI_low.append(udi_low)
        UDI_up.append(udi_up)
    DA = list_to_data_tree(DA)
    UDI = list_to_data_tree(UDI)
    UDI_low = list_to_data_tree(UDI_low)
    UDI_up = list_to_data_tree(UDI_up)


# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Write a Honeybee Model to a Radiance Model Folder.
_
This Radiance Model Folder is what is used to run various types of Radiance
studies off of a consistent set of geometry and modifiers.

-

    Args:
        _model: A honeybee model object possessing all geometry, radiance modifiers
            and simulation assets like Sensor Grids and Views.
        _folder_: An optional folder to into which the Model Radiance Folder
            will be written. NOTE THAT DIRECTORIES INPUT HERE SHOULD NOT HAVE
            ANY SPACES OR UNDERSCORES IN THE FILE PATH.
        _write: Set to True to write the Model to a Radiance folder.

    Returns:
        report: Reports, errors, warnings, etc.
        folder: Path to the folder in which all of the files have been written.
"""

ghenv.Component.Name = 'HB Model to Rad Folder'
ghenv.Component.NickName = 'ModelToRad'
ghenv.Component.Message = '1.2.0'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '4 :: Results'
ghenv.Component.AdditionalHelpFromDocStrings = '0'

import os

try:
    from ladybug.futil import write_to_file_by_name, nukedir, preparedir
except ImportError as e:
    raise ImportError('\nFailed to import ladybug:\n\t{}'.format(e))

try:
    from honeybee.config import folders
except ImportError as e:
    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))

try:
    from honeybee_radiance_folder.folder import ModelFolder
except ImportError as e:
    raise ImportError('\nFailed to import honeybee_radiance_folder:\n\t{}'.format(e))

try:
    from ladybug_rhino.grasshopper import all_required_inputs, give_warning
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component) and _write:
    # process the simulation folder name and the directory
    _folder_ = folders.default_simulation_folder if _folder_ is None else _folder_
    folder = os.path.join(_folder_, _model.identifier, 'Radiance')
    if os.path.isdir(folder):
        nukedir(folder, rmdir=True)  # delete the folder if it already exists
    else:
        preparedir(folder)  # create the directory if it's not there

    # write the model folder
    _model.to.rad_folder(_model, folder)



# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>


"""
Deconstruct a modifier set into its constituient exterior modifiers.
-

    Args:
        _mod_set: A modifier set to be deconstructed. This can also be
            text for a modifier set to be looked up in the modifier
            set library.

    Returns:
        exterior_wall: A modifier object for the set's exterior walls.
        exterior_roof: A modifier object for the set's exterior roofs.
        exposed_floor: A modifier object for the set's exposed floors.
        ground_wall: A modifier object for the set's underground walls.
        ground_roof: A modifier object for the set's underground roofs.
        ground_floor: A modifier object for the set's ground-contact floors.
        window: A modifier object for apertures with an Outdoors boundary
            condition and a Wall face type for their parent face.
        skylight: A modifier object for apertures with an Outdoors boundary
            condition and a RoofCeiling or Floor face type for their parent face.
        operable: A modifier object for apertures with an Outdoors boundary
            condition and True is_operable property.
        exterior_door: A modifier object for opaque doors with an Outdoors
            boundary condition and a Wall face type for their parent face.
        overhead_door: A modifier object for opaque doors with an Outdoors
            boundary condition and a RoofCeiling or Floor face type for their
            parent face.
        glass_door: A modifier object for all glass doors with an Outdoors
            boundary condition.
        exterior_shade: A modifier object for all exterior shades.
"""

ghenv.Component.Name = 'HB Deconstruct ModifierSet'
ghenv.Component.NickName = 'DecnstrModSet'
ghenv.Component.Message = '1.2.0'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '1 :: Modifiers'
ghenv.Component.AdditionalHelpFromDocStrings = '5'


try:  # import the honeybee-radiance dependencies
    from honeybee_radiance.modifierset import ModifierSet
    from honeybee_radiance.lib.modifiersets import modifier_set_by_identifier
except ImportError as e:
    raise ImportError('\nFailed to import honeybee_radiance:\n\t{}'.format(e))

try:  # import ladybug_rhino dependencies
    from ladybug_rhino.grasshopper import all_required_inputs
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component):
    # check the input
    if isinstance(_mod_set, str):
        _mod_set = modifier_set_by_identifier(_mod_set)
    else:
        assert isinstance(_mod_set, ModifierSet), \
            'Expected ModifierSet. Got {}.'.format(type(_mod_set))

    exterior_wall = _mod_set.wall_set.exterior_modifier
    exterior_roof = _mod_set.roof_ceiling_set.exterior_modifier
    exposed_floor = _mod_set.floor_set.exterior_modifier
    window = _mod_set.aperture_set.window_modifier
    skylight = _mod_set.aperture_set.skylight_modifier
    operable = _mod_set.aperture_set.operable_modifier
    exterior_door = _mod_set.door_set.exterior_modifier
    overhead_door = _mod_set.door_set.overhead_modifier
    glass_door = _mod_set.door_set.exterior_glass_modifier
    exterior_shade = _mod_set.shade_set.exterior_modifier



# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Run an annual daylight study for a Honeybee model.

-
    Args:
        _model: A Honeybee Model for which Annual Daylight will be simulated.
            Note that this model should have grids assigned to it in order
            to produce meaningfule results.
        _wea: A Wea object produced from the Wea components that are under the Light
            Sources tab. This can also be the path to a .wea or a .epw file.
        north_: A number between -360 and 360 for the counterclockwise difference
            between the North and the positive Y-axis in degrees. This can
            also be Vector for the direction to North. (Default: 0).
        _thresholds_: A string to change the threshold for daylight autonomy and useful
            daylight illuminance. Valid keys are -t for daylight autonomy threshold,
            -lt for the lower threshold for useful daylight illuminance and
            -ut for the upper threshold. The order of the keys is not important
            and you can include one or all of them. For instance if you only want
            to change the upper threshold to 2000 lux you should use -ut 2000
            as the input. (Default: -t 300 -lt 100 -ut 3000).
        _schedule_: An annual occupancy schedule, either as a Ladybug Hourly Continuous
            Data Collection or a HB-Energy schedule object. This can also be the
            path to a CSV file with 8760 rows or the identifier of a schedule in
            the honeybee-energy schedule library. Any value in this schedule
            that is 0.1 or above will be considered occupied.
        grid_filter_: Text for a grid identifer or a pattern to filter the sensor grids of
            the model that are simulated. For instance, first_floor_* will simulate
            only the sensor grids that have an identifier that starts with
            first_floor_. By default, all grids in the model will be simulated.
        sensor_count_: Integer for the maximum number of sensor grid points per
            parallel execution. (Default: 200).
        radiance_par_: Text for the radiance parameters to be used for ray
            tracing. (Default: -ab 2 -ad 5000 -lw 2e-05).
        run_settings_: Settings from the "HB Recipe Settings" component that specify
            how the recipe should be run. This can also be a text string of
            recipe settings.
        _run: Set to True to run the recipe and get results.

    Returns:
        report: Reports, errors, warnings, etc.
        results: Folder with raw result files (.ill) that contain illuminance matrices.
        DA: Daylight autonomy results.
        cDA: Continuous daylight autonomy results.
        UDI: Useful daylight illuminance results.
        UDI_low: Results for the percent of time that is below the lower threshold
            of useful daylight illuminance.
        UDI_up: Results for the percent of time that is above the upper threshold
            of useful daylight illuminance.
"""

ghenv.Component.Name = 'HB Annual Daylight'
ghenv.Component.NickName = 'AnnualDaylight'
ghenv.Component.Message = '1.2.2'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '3 :: Recipes'
ghenv.Component.AdditionalHelpFromDocStrings = '1'

try:
    from lbt_recipes.recipe import Recipe
except ImportError as e:
    raise ImportError('\nFailed to import lbt_recipes:\n\t{}'.format(e))

try:
    from ladybug_rhino.grasshopper import all_required_inputs, recipe_result
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component) and _run:
    # create the recipe and set the input arguments
    recipe = Recipe('annual-daylight')
    recipe.input_value_by_name('model', _model)
    recipe.input_value_by_name('wea', _wea)
    recipe.input_value_by_name('north', north_)
    recipe.input_value_by_name('thresholds', _thresholds_)
    recipe.input_value_by_name('schedule', _schedule_)
    recipe.input_value_by_name('grid-filter', grid_filter_)
    recipe.input_value_by_name('sensor-count', sensor_count_)
    recipe.input_value_by_name('radiance-parameters', radiance_par_)

    # run the recipe
    project_folder = recipe.run(run_settings_, radiance_check=True)

    # load the results
    results = recipe_result(recipe.output_value_by_name('results', project_folder))
    DA = recipe_result(recipe.output_value_by_name('da', project_folder))
    cDA = recipe_result(recipe.output_value_by_name('cda', project_folder))
    UDI = recipe_result(recipe.output_value_by_name('udi', project_folder))
    UDI_low = recipe_result(recipe.output_value_by_name('udi-lower', project_folder))
    UDI_up = recipe_result(recipe.output_value_by_name('udi-upper', project_folder))



# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2021, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Calculate the number of hours of direct sun received by grids of sensors in a
Honeybee model.

-
    Args:
        _model: A Honeybee Model for which Direct Sun Hours will be simulated.
            Note that this model should have grids assigned to it in order
            to produce meaningfule results.
        _wea: A Wea object produced from the Wea components that are under the Light
            Sources tab. This can also be the path to a .wea or a .epw file.
        north_: A number between -360 and 360 for the counterclockwise difference
            between the North and the positive Y-axis in degrees. This can
            also be Vector for the direction to North. (Default: 0).
        grid_filter_: Text for a grid identifer or a pattern to filter the sensor grids of
            the model that are simulated. For instance, first_floor_* will simulate
            only the sensor grids that have an identifier that starts with
            first_floor_. By default, all grids in the model will be simulated.
        sensor_count_: Integer for the maximum number of sensor grid points per
            parallel execution. (Default: 200).
        run_settings_: Settings from the "HB Recipe Settings" component that specify
            how the recipe should be run. This can also be a text string of
            recipe settings.
        _run: Set to True to run the recipe and get results.

    Returns:
        report: Reports, errors, warnings, etc.
        results: Folder with raw result files (.ill) that contain the number of timesteps
            that each sensor is exposed to sun. The units are the timestep of
            input wea file. For an hourly wea, each value corresponds to an hour
            of direct sun.
        hours: The cumulative number of timesteps that each sensor sees the sun. If the input
            wea timestep is 1, the results are the number of direct sun hours.
"""

ghenv.Component.Name = 'HB Direct Sun Hours'
ghenv.Component.NickName = 'DirectSunHours'
ghenv.Component.Message = '1.2.2'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '3 :: Recipes'
ghenv.Component.AdditionalHelpFromDocStrings = '1'

try:
    from lbt_recipes.recipe import Recipe
except ImportError as e:
    raise ImportError('\nFailed to import lbt_recipes:\n\t{}'.format(e))

try:
    from ladybug_rhino.grasshopper import all_required_inputs, recipe_result
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component) and _run:
    # create the recipe and set the input arguments
    recipe = Recipe('direct-sun-hours')
    recipe.input_value_by_name('model', _model)
    recipe.input_value_by_name('wea', _wea)
    recipe.input_value_by_name('north', north_)
    recipe.input_value_by_name('grid-filter', grid_filter_)
    recipe.input_value_by_name('sensor-count', sensor_count_)

    # run the recipe
    project_folder = recipe.run(run_settings_, radiance_check=True)

    # load the results
    results = recipe_result(recipe.output_value_by_name('direct-sun-hours', project_folder))
    hours = recipe_result(recipe.output_value_by_name('cumulative-sun-hours', project_folder))
